/* -*- Mode: C; c-basic-offset: 4; indent-tabs-mode: nil -*- */
/*
   Copyright (C) 2010 Red Hat, Inc.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _H_ZLIB_DECODER
#define _H_ZLIB_DECODER

#include "common.h"
#include "red_canvas_base.h"

#ifndef __GNUC__
#define ZLIB_WINAPI
#endif
#include <zlib.h>


class ZlibDecoder : public SpiceZlibDecoder {
public:
    ZlibDecoder();
    ~ZlibDecoder();

    void decode(uint8_t *data, int data_size, uint8_t *dest, int dest_size);

private:
    z_stream _z_strm;

};

#endif
